@@ -160,33 +160,52 @@ class Smartfox():
         self.lastUpdate = datetime.now()
         return True
 
-    def parseXML(self, resp):
+    def parseXML(self, resp) -> None:
+        """parsing the XML response from the SmartFox device to get the values by id"""
         tree = ElementTree.parse(io.StringIO(resp.content.decode("utf-8")))
         root = tree.getroot()
         values = {}
         for element in root:
             values[element.attrib.get("id")] = element.text
         self.values = values
-        
-    def getValues(self):
-        """Get all values from the SmartFox device"""
+
+    def getValues(self) -> bool:
+        """Get all values from the SmartFox device, by using requests.get and to retrieve the xml file"""
         resp = requests.get(f"{self.scheme}://{self.host}/{self.valuesPath}", verify=self.verify)
         if resp.status_code == 200:
             self.parseXML(resp)
             return self.updateValues()
 
+    # def setRelayOld(self, relay: Relay, state: bool) -> bool:
+    #     """Set a relay on the SmartFox device"""
+    #     resp = requests.get(f"{self.scheme}://{self.host}/setswrel.cgi?rel={relay.id}&state={'1' if state else '0'}", verify=self.verify)
+    #     if resp.status_code == 200:
+    #         self.updateValues(self.parseXML(resp))
+    #         return True
+    #     return False
+
     def setRelay(self, relay: Relay, state: bool) -> bool:
         """Set a relay on the SmartFox device"""
-        resp = requests.get(f"{self.scheme}://{self.host}/setswrel.cgi?rel={relay.id}&state={'1' if state else '0'}", verify=self.verify)
+        resp = requests.get(f"{self.scheme}://{self.host}/setswrel.cgi?rel={relay.id}&state={state}", verify=self.verify)
         if resp.status_code == 200:
-            self.updateValues(self.parseXML(resp))
+            self.parseXML(resp)
+            self.updateValues()
             return True
         return False
 
+    # def setAnalogOld(self, value: int, mode: int = 0)  -> bool:
+    #     """Set the analog output on the SmartFox device"""
+    #     resp = requests.get(f"{self.scheme}://{self.host}/setswaout.cgi?mode={mode}&power={value}", verify=self.verify)
+    #     if resp.status_code == 200:
+    #         self.updateValues(self.parseXML(resp))
+    #         return True
+    #     return False
+
     def setAnalog(self, value: int, mode: int = 0)  -> bool:
         """Set the analog output on the SmartFox device"""
         resp = requests.get(f"{self.scheme}://{self.host}/setswaout.cgi?mode={mode}&power={value}", verify=self.verify)
         if resp.status_code == 200:
-            self.updateValues(self.parseXML(resp))
+            self.parseXML(resp)
+            self.updateValues()
             return True
         return False
\ No newline at end of file
