@@ -194,11 +194,14 @@ class Relay():
             self._state = None
         
     def turnOn(self) -> None:
-        self.smartfox.setRelay(relay=self, state=True)
+        self.smartfox.setRelay(relay=self, state=1)
         
     def turnOff(self) -> None:
-        self.smartfox.setRelay(relay=self, state=False)
-        
+        self.smartfox.setRelay(relay=self, state=2)
+
+    def setAuto(self) -> None: #set Auto
+        self.smartfox.setRelay(relay=self, state=0)
+
     state = property(getState, setState)
     
     def __str__(self):
@@ -235,13 +238,13 @@ class AnalogOut():
         self.power = PowerValue()
         self.smartfox = smartfox
         
-    def set(self, value) -> None: #Set Manuell
+    def turnOn(self, value) -> None: #Set On
         self.smartfox.setAnalog(value=value, mode=1)
 
     def setAuto(self) -> None: #set Auto
         self.smartfox.setAnalog(value=0, mode=2)
 
-    def off(self) -> None: #Set off
+    def turnOff(self) -> None: #Set off
         self.smartfox.setAnalog(value=0, mode=0)
         
     def __str__(self):
